isCurrentAt method

bool isCurrentAt(
  1. DateTime now, {
  2. Duration maxAge = PdfAatl.maxAge,
})

Whether the file was signed no more than maxAge before now. A snapshot with no signing time is never current.

Implementation

bool isCurrentAt(DateTime now, {Duration maxAge = PdfAatl.maxAge}) {
  final signed = signedAt;
  return signed != null && now.difference(signed) <= maxAge;
}