expires property
The earliest NextUpdate among the LOTL and every list whose anchors are included - past it (plus pdfTrustListExpiryGrace) some of those lists are expired and the snapshot must not be used.
Implementation
final DateTime? expires;
The earliest NextUpdate among the LOTL and every list whose anchors are included - past it (plus pdfTrustListExpiryGrace) some of those lists are expired and the snapshot must not be used.
final DateTime? expires;