XmlC14nMethod enum
Canonical XML flavours used by XML signatures.
Values
- inclusive → const XmlC14nMethod
-
Canonical XML 1.0 (
http://www.w3.org/TR/2001/REC-xml-c14n-20010315). - exclusive → const XmlC14nMethod
-
Exclusive XML Canonicalization 1.0 (
http://www.w3.org/2001/10/xml-exc-c14n#).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromUri(
String uri) → XmlC14nMethod?
Constants
-
values
→ const List<
XmlC14nMethod> - A constant List of the values in this enum, in order of their declaration.