child method
The first child element with local name local, or null.
Implementation
XmlLiteElement? child(String local) {
for (final e in childElements) {
if (e.localName == local) return e;
}
return null;
}
The first child element with local name local, or null.
XmlLiteElement? child(String local) {
for (final e in childElements) {
if (e.localName == local) return e;
}
return null;
}