PdfFieldType enum
What kind of input a form field accepts, derived from /FT plus the discriminating /Ff bits (12.7.4).
Values
- text → const PdfFieldType
- checkBox → const PdfFieldType
- radioGroup → const PdfFieldType
- pushButton → const PdfFieldType
- comboBox → const PdfFieldType
- listBox → const PdfFieldType
- signature → const PdfFieldType
- unknown → const PdfFieldType
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PdfFieldType> - A constant List of the values in this enum, in order of their declaration.