PdfTrustListPointer class

A pointer in the LOTL to one Member State's list.

Constructors

PdfTrustListPointer(String territory, Uri location, List<X509Certificate> signers)

Properties

hashCode → int
The hash code for this object.
no setterinherited
location → Uri
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
signers → List<X509Certificate>
The certificates allowed to sign that list.
final
territory → String
ISO 3166 country code (e.g. DE).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited